summaryrefslogtreecommitdiff
path: root/tools/binman/etype/entry.py
diff options
context:
space:
mode:
Diffstat (limited to 'tools/binman/etype/entry.py')
-rw-r--r--tools/binman/etype/entry.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/binman/etype/entry.py b/tools/binman/etype/entry.py
index 23e436a2e9..39da7f8602 100644
--- a/tools/binman/etype/entry.py
+++ b/tools/binman/etype/entry.py
@@ -203,10 +203,10 @@ class Entry(object):
def ProcessContents(self):
pass
- def WriteSymbols(self, image):
+ def WriteSymbols(self, section):
"""Write symbol values into binary files for access at run time
Args:
image: Image containing the entry
"""
pass
@@ -203,10 +203,10 @@ class Entry(object):
"""Write symbol values into binary files for access at run time
Args:
- image: Image containing the entry
+ section: Section containing the entry
"""
pass